@@ -13,18 +13,31 @@ t.test('read from an index.js file', t => {
       description: 'Did you know npm could do this, even?',
       main: 'index.js',
       readme: 'ERROR: No README data found!',
-      _id: 'indexjs-test@1.2.3'
+      _id: 'indexjs-test@1.2.3',
     })
     t.end()
   })
 })
 
-t.test('read broken json', t => {
-  const fixture = resolve(__dirname, 'fixtures/indexjs-bad/package.json')
+t.test('missing file', t => {
+  // this subdirectory does not exist
+  const fixture = resolve(__dirname, 'fixtures/indexjs-missing/package.json')
   read(fixture, (er, data) => {
     t.match(er, {
       code: 'ENOENT',
-      path: fixture
+      path: fixture,
+    })
+    t.notOk(data)
+    t.end()
+  })
+})
+
+t.test('EJSONPARSE', t => {
+  const fixture = resolve(__dirname, 'fixtures/indexjs-bad/package.json')
+  read(fixture, (er, data) => {
+    t.match(er, {
+      code: 'EJSONPARSE',
+      path: fixture,
     })
     t.notOk(data)
     t.end()
